@@ -10,6 +10,9 @@ our $VERSION = "0.01";
 use lib 't/lib';
 use Data::Dumper qw(Dumper);
 require Encode;
-use Dummy;    # does not exist
+
+# use CommentOuted; # will be ignored
+my $dummys = 1;    # use CommentOuted; # will be ignored
+use Dummy;         # does not exist
 
 exit;
