@@ -9,6 +9,9 @@ our $VERSION = "0.01";
 
 use Data::Dumper qw(Dumper);
 require Encode;
+
+# use parent "CommentOuted";    # does not exist
+my $dummys = 1;        # use parent "CommentOuted"; # will be ignored
 use parent "Dummy";    # does not exist
 
 exit;
